package com.diagbot.facade;

import com.diagbot.client.ICSSServiceClient;
import com.diagbot.dto.EMRIntroduceDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.enums.TypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.EMRInfoVO;
import com.diagbot.vo.EMRIntroduceVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2019/3/11 13:09
 */
@Component
public class EMRInfoFacade {
    @Autowired
    private TranLisConfigFacade tranLisConfigFacade;
    @Autowired
    private PacsConfigFacade pacsConfigFacade;
    @Autowired
    private IntroduceTitleConfigFacade introduceTitleConfigFacade;
    @Autowired
    private ICSSServiceClient icssServiceClient;

    public List<EMRIntroduceDTO> getEMRInfo(EMRInfoVO emrInfoVO) {
        String hoscode = emrInfoVO.getHosCode();
        Map<String, Map<String, String>> lisConfigMap = tranLisConfigFacade.getLisConfigByHosCode(hoscode);
        Map<String, String> pacsConfigMap = pacsConfigFacade.getPacsConfigByHosCode(hoscode);
        Map<String, String> titleMappingMap = introduceTitleConfigFacade.getTitleMappingHosCode(hoscode);

        //公表转换
        String uniqueName = "";
        Integer type = emrInfoVO.getType();
        if (type.equals(TypeEnum.Lis)) {
            uniqueName = lisConfigMap.get(emrInfoVO.getMealName()).get(emrInfoVO.getItemName());
        } else if (type.equals(TypeEnum.Pacs)) {
            uniqueName = pacsConfigMap.get(emrInfoVO.getMealName());
        }

        //未找到公表映射项目
        if (uniqueName == null || StringUtil.isBlank(uniqueName)) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "项目未找到");
        }

        String[] titles = emrInfoVO.getTitles();
        List<String> titleList = Lists.newLinkedList();
        if (titles.length > 0) {
            for (String title : titles) {
                String innerTitle = titleMappingMap.get(title);
                if (StringUtil.isNotBlank(innerTitle)) {
                    titleList.add(innerTitle);
                }
            }
        }

        //标题转换
        EMRIntroduceVO introduceVO = new EMRIntroduceVO();
        introduceVO.setName(uniqueName);
        introduceVO.setType(type);
        if (titleList.size() > 0) {
            String[] mappingTitles = null;
            introduceVO.setTitles(titleList.toArray(mappingTitles));
        }

        RespDTO<List<EMRIntroduceDTO>> respDTO = icssServiceClient.getIntroduceByEMR(introduceVO);
        List<EMRIntroduceDTO> emrIntroduceDTOList = respDTO.data;
        return emrIntroduceDTOList;
    }
}
